@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 Organize Django settings into multiple files and directories.
 
@@ -7,21 +5,23 @@ Easily override and modify settings. Use wildcards and optional
 settings files.
 """
 
+from __future__ import annotations
+
 import glob
-import inspect
 import os
 import sys
+import typing
 from importlib.util import module_from_spec, spec_from_file_location
 
 __all__ = ('optional', 'include')  # noqa: WPS410
 
-#: Special magic attribute that is sometimes set by `uwsgi` / `gunicord`.
+#: Special magic attribute that is sometimes set by `uwsgi` / `gunicorn`.
 _INCLUDED_FILE = '__included_file__'
 
 
-def optional(filename: str) -> str:
+def optional(filename: typing.Optional[str]) -> str:
     """
-    This functions is used for compatibility reasons.
+    This function is used for compatibility reasons.
 
     It masks the old `optional` class with the name error.
     Now `invalid-name` is removed from `pylint`.
@@ -33,22 +33,32 @@ def optional(filename: str) -> str:
         New instance of :class:`_Optional`.
 
     """
-    return _Optional(filename)
+    return _Optional(filename or '')
 
 
 class _Optional(str):  # noqa: WPS600
     """
     Wrap a file path with this class to mark it as optional.
 
-    Optional paths don't raise an :class:`IOError` if file is not found.
+    Optional paths don't raise an :class:`OSError` if file is not found.
     """
 
 
-def include(*args: str, **kwargs) -> None:  # noqa: WPS210, WPS231, C901
+def include(  # noqa: WPS210, WPS231, C901
+    *args: str,
+    scope: dict[str, typing.Any] | None = None,
+) -> None:
     """
     Used for including Django project settings from multiple files.
 
-    Usage:
+    Args:
+        *args: File paths (``glob`` - compatible wildcards can be used).
+        **kwargs: Settings context: ``scope=globals()`` or ``None``.
+
+    Raises:
+        OSError: if a required settings file is not found.
+
+    Usage example:
 
     .. code:: python
 
@@ -62,20 +72,13 @@ def include(*args: str, **kwargs) -> None:  # noqa: WPS210, WPS231, C901
             scope=globals(),  # optional scope
         )
 
-    Args:
-        *args: File paths (``glob`` - compatible wildcards can be used).
-        **kwargs: Settings context: ``scope=globals()`` or ``None``.
-
-    Raises:
-        IOError: if a required settings file is not found.
-
     """
     # we are getting globals() from previous frame
     # globals - it is caller's globals()
-    scope = kwargs.pop('scope', inspect.stack()[1][0].f_globals)
+    scope = scope or sys._getframe(1).f_globals  # noqa: WPS437
 
     scope.setdefault('__included_files__', [])
-    included_files = scope.get('__included_files__')
+    included_files = scope.get('__included_files__', [])
 
     including_file = scope.get(
         _INCLUDED_FILE,
@@ -91,7 +94,7 @@ def include(*args: str, **kwargs) -> None:  # noqa: WPS210, WPS231, C901
         # (unless file is optional)
         files_to_include = glob.glob(pattern)
         if not files_to_include and not isinstance(conf_file, _Optional):
-            raise IOError('No such file: {0}'.format(pattern))
+            raise OSError('No such file: {0}'.format(pattern))
 
         for included_file in files_to_include:
             included_file = os.path.abspath(included_file)  # noqa: WPS440
@@ -114,9 +117,9 @@ def include(*args: str, **kwargs) -> None:  # noqa: WPS210, WPS231, C901
                 rel_path[:rel_path.rfind('.')].replace('/', '.'),
             )
 
-            spec = spec_from_file_location(
-                module_name, included_file,
-            )
+            spec = spec_from_file_location(module_name, included_file)
+            # This is only needed for mypy:
+            assert spec is not None  # noqa: S101
             module = module_from_spec(spec)
             sys.modules[module_name] = module
         if saved_included_file:
