@@ -1,9 +1,6 @@
-# -*- coding: utf-8 -*-
-
 import os
 
 import pytest
-import six
 
 from split_settings.tools import include
 
@@ -11,8 +8,8 @@ _FIXTURE_VALUE = 'FIXTURE_VALUE'
 
 
 def test_missing_file_error(scope):
-    """This test covers the IOError, when file does not exist."""
-    with pytest.raises(IOError, match='does-not-exist.py'):
+    """This test covers the OSError, when file does not exist."""
+    with pytest.raises(OSError, match='does-not-exist.py'):
         include('does-not-exist.py', scope=scope)
 
 
@@ -48,10 +45,7 @@ def test_empty_included_file(scope, fixture_file):
 
 def test_unicode_passed(scope, fixture_file):
     """Tests the `unicode` filename in `python2`."""
-    include(
-        six.text_type(fixture_file),  # unicode on py2, str on py3
-        scope=scope,
-    )
+    include(fixture_file, scope=scope)
     assert _FIXTURE_VALUE in scope
 
 
